==> insteonplm-0.8.1.tar.gz: insteonplm-0.8.1/insteonplm/devices/securityHealthSafety.py <==
from .devicebase import DeviceBase
from insteonplm.constants import *
from insteonplm.states.sensor import VariableSensor, MotionSensor, SmokeCO2Sensor

class SecurityHealthSafety(DeviceBase):
    """Security Health Safety Control Device Class 0x10
    
    INSTEON Security Health Safety Control Device Class. 
    These are typically binary sensors with On/Off status.
    There are no state change commands that can be sent to the device.
    
    To monitor the state of the device subscribe to the state monitor:
         - sensor.connect(callback)  (state='Sensor')
    where callback defined as:
        - callback(self, device_id, state, state_value)
    """

    def __init__(self, plm, address, cat, subcat, product_key=None, description=None, model=None):
        super().__init__(plm, address, cat, subcat, product_key, description, model)
        
        self._stateList[0x01] = VariableSensor(self._address, "onOffSensor", 0x01, self._send_msg, self._plm.message_callbacks, 0x00)

class SecurityHealthSafety_2842_222(DeviceBase):
    
    def __init__(self, plm, address, cat, subcat, product_key=None, description=None, model=None):
        super().__init__(plm, address, cat, subcat, product_key, description, model)

        self._product_data_in_aldb = True
        
        self._stateList[0x01] = MotionSensor(self._address, "motionSensor", 0x01, self._send_msg, self._plm.message_callbacks, 0x00)
            
class SecurityHealthSafety_2982_222(DeviceBase):
    
    def __init__(self, plm, address, cat, subcat, product_key=None, description=None, model=None):
        super().__init__(plm, address, cat, subcat, product_key, description, model)
        
        self._stateList[0x01] = SmokeCO2Sensor(self._address, "smokeCO2Sensor", 0x01, self._send_msg, self._plm.message_callbacks, 0x00)

==> insteonplm-0.8.2.tar.gz: insteonplm-0.8.2/insteonplm/devices/securityHealthSafety.py <==
from .devicebase import DeviceBase
from insteonplm.constants import *
from insteonplm.states.sensor import (VariableSensor, OnOffSensor, SmokeCO2Sensor)

class SecurityHealthSafety(DeviceBase):
    """Security Health Safety Control Device Class 0x10
    
    INSTEON Security Health Safety Control Device Class. 
    These are typically binary sensors with On/Off status.
    There are no state change commands that can be sent to the device.
    
    To monitor the state of the device subscribe to the state monitor:
         - sensor.connect(callback)  (state='Sensor')
    where callback defined as:
        - callback(self, device_id, state, state_value)
    """

    def __init__(self, plm, address, cat, subcat, product_key=None, description=None, model=None):
        super().__init__(plm, address, cat, subcat, product_key, description, model)

        self._product_data_in_aldb = True
        
        self._stateList[0x01] = VariableSensor(self._address, "generalSensor", 0x01, self._send_msg, self._plm.message_callbacks, 0x00)

class SecurityHealthSafety_2421(DeviceBase):
    
    def __init__(self, plm, address, cat, subcat, product_key=None, description=None, model=None):
        super().__init__(plm, address, cat, subcat, product_key, description, model)

        self._product_data_in_aldb = True
        
        self._stateList[0x01] = OnOffSensor(self._address, "openClosedSensor", 0x01, self._send_msg, self._plm.message_callbacks, 0x00)
       
class SecurityHealthSafety_2842_222(DeviceBase):
    
    def __init__(self, plm, address, cat, subcat, product_key=None, description=None, model=None):
        super().__init__(plm, address, cat, subcat, product_key, description, model)

        self._product_data_in_aldb = True
        
        self._stateList[0x01] = OnOffSensor(self._address, "motionSensor", 0x01, self._send_msg, self._plm.message_callbacks, 0x00)
                
class SecurityHealthSafety_2845_2222(DeviceBase):
    
    def __init__(self, plm, address, cat, subcat, product_key=None, description=None, model=None):
        super().__init__(plm, address, cat, subcat, product_key, description, model)

        self._product_data_in_aldb = True
        
        self._stateList[0x01] = OnOffSensor(self._address, "doorSensor", 0x01, self._send_msg, self._plm.message_callbacks, 0x00)

class SecurityHealthSafety_2852_222(DeviceBase):
    
    def __init__(self, plm, address, cat, subcat, product_key=None, description=None, model=None):
        super().__init__(plm, address, cat, subcat, product_key, description, model)

        self._product_data_in_aldb = True
        
        self._stateList[0x01] = OnOffSensor(self._address, "leakSensor", 0x01, self._send_msg, self._plm.message_callbacks, 0x00)
                
class SecurityHealthSafety_2982_222(DeviceBase):
    
    def __init__(self, plm, address, cat, subcat, product_key=None, description=None, model=None):
        super().__init__(plm, address, cat, subcat, product_key, description, model)

        self._product_data_in_aldb = True
        
        self._stateList[0x01] = SmokeCO2Sensor(self._address, "smokeCO2Sensor", 0x01, self._send_msg, self._plm.message_callbacks, 0x00)
